const path = require("path");

function isFunction(functionToCheck) {
  return functionToCheck && {}.toString.call(functionToCheck) === '[object Function]';
}

module.exports = {
  stories: ["../src/**/*.stories.js"],
  addons: [
    "@storybook/addon-actions",
    "@storybook/addon-a11y/register",
    '@storybook/addon-storysource',
    '@storybook/addon-docs',
    '@storybook/addon-controls',
    'storybook-addon-xd-designs/register',
  ],
  webpackFinal: async (config) => {
    const fileLoaderRule = config.module.rules.find(rule => rule.test && isFunction(rule.test.test) && rule.test.test('.svg'));
    fileLoaderRule.exclude = /\.svg$/;

    config.module.rules.push(
      { test: /\.(png|jpg|svg)$/i, issuer: /\.scss$/, use: "url-loader" },
      {
        test: /\.svg$/,
        exclude: /login/,
        issuer: /\.js$/,
        use: ["@svgr/webpack"],
      },
      {
        test: /\.scss$/i,
        use: ["style-loader", "css-loader", "sass-loader"],
        include: path.resolve(__dirname, "../")
      },
      {
        test: /\.(woff|woff2)$/,
        use: [
          {
            loader: 'file-loader',
            query: {
              name: '[name].[ext]'
            }
          }
        ],
        include: path.resolve(__dirname, "../")
      });

    return config;
  }
};
