import React, {useCallback, useState} from 'react';
import isUndefined from 'lodash/isUndefined';
import PropTypes from "prop-types";

const Formidable = React.forwardRef((props, ref) => {
  const {
    Component,
    form,
    name,
    onChange: _onChange,
    value: _value,
    errorMessage: _errorMessage,
    showError: _showError,
    onBlur: _onBlur,
    useHandleFormChangeWrapper
  } = props;
  const [wasFocused, setWasFocused] = useState(false);
  const {onChange, value, errorMessage, showError} = formHandler({
    _onChange,
    _value,
    _errorMessage,
    _showError,
    form,
    name,
    wasFocused,
    useHandleFormChangeWrapper
  });

  const onBlur = useCallback((e) => {
    setWasFocused(true);
    _onBlur && _onBlur(e);
  }, [setWasFocused, _onBlur]);

  return <Component onBlur={onBlur} {...props} onChange={onChange} value={value}
                    error={showError && errorMessage} ref={ref}/>
});

const formHandler = ({
                              _onChange,
                              _value,
                              _showError,
                              _errorMessage,
                              form,
                              name,
                              useHandleFormChangeWrapper,
                              wasFocused
                            }) => {
  let onChange = _onChange;
  let value = _value;
  let errorMessage = _errorMessage;
  let showError = _showError;
  if (form && name) {
    value = _value || form.formState[name];
    onChange = _onChange || (useHandleFormChangeWrapper ? form.wrappedHandleFormChange(name) : form.handleFormChange);
    errorMessage = _errorMessage || form.formErrors[name];
    if(isUndefined(_showError)) {
      showError = (form.submissionAttempted || (form.dirty[name] && wasFocused)) && form.formErrors[name]
    }
  }

  return {onChange, value, errorMessage, showError};
};

export default React.forwardRef((props, ref) => {
  return <Formidable {...props} ref={ref} />
});
