import React from 'react'
import Select from './index'
import { compareSnapshotAndScreenshot } from '../../testUtils'
import {SELECT_TYPES} from "../../consts";

export default {
  title: 'Design System/Select',
  component: Select
}

const Template = (args) => <Select {...args} />
const TemplateWithMore = (args) => <div><Select {...args} />
  <div>Additional components goes here</div>
</div>

const options = [
  { label: 'label1', value: 'value1' },
  { label: 'label2', value: 'value2' },
  { label: 'label3', value: 'value3', disabled: true, disabledTitle: 'This is a disabled option' },
  { label: 'label4', value: 'value4' },
  { label: 'label5', value: 'value5' },
  { label: 'label6', value: 'value6' }
]

const optionsWithSecondaryLabel = options.map((option, index) => ({
  ...option,
  label2: `additional label ${index}`
}))

export const Default = Template.bind({})
Default.args = {
  options,
  label: 'Label',
  isClearable: true
}

export const withInfo = Template.bind({})
withInfo.args = {
  options,
  label: 'Label',
  info: 'This is a tooltip'
}

export const withError = TemplateWithMore.bind({})
withError.args = {
  options,
  label: 'Label',
  error: 'This is an error'
}

export const twoLines = Template.bind({})
twoLines.args = {
  options: optionsWithSecondaryLabel,
  label: 'Options with 2 lines',
  variant: SELECT_TYPES.TWO_LINES,
  placeholder: 'default-placeholder'
}

export const noOptions = Template.bind({})
noOptions.args = {
  label: 'No Options',
  placeholder: 'no options placeholder'
}

export const inline = Template.bind({})
inline.args = {
  options,
  variant: SELECT_TYPES.INLINE,
  placeholder: 'inline-placeholder'
}

export const underline = Template.bind({})
underline.args = {
  options,
  variant: SELECT_TYPES.UNDERLINE,
  placeholder: 'underline-placeholder'
}

export const menuAppendToBody = Template.bind({})
menuAppendToBody.args = {
  options,
  styles: { menuPortal: base => ({ ...base, zIndex: 9999 }) },
  menuPortalTarget: document.body
}

export const enableOptionsAdding = Template.bind({})
enableOptionsAdding.args = {
  options,
  label: 'Label',
  info: 'This is a tooltip',
  enableOptionsAdding: true,
  isClearable: true
}

twoLines.parameters = {
  async puppeteerTest(page) {
    const element = await page.$('.Suc-Select-container')
    await element.click() // open select menu
    await page.waitForTimeout(1000)
    await compareSnapshotAndScreenshot(page)
  }
}
