import React from 'react'
import TooltipInfo from '../TooltipInfo'
import PropTypes from 'prop-types'
import FieldExtra from '../FieldExtra'
import './textInput.scss'

const TextInput = ({ className, type, label, error, warning, disabled, optional, info, infoProps, removeBottomMargin, ...rest }) => {
  return <div
    className={`Suc-text-input ${disabled ? 'Suc-disabled' : ''} ${className} ${removeBottomMargin ? '' : 'Suc-bottom-margin'}`}>
    <div className={'Suc-input-top'}>
      {label && <label className={'Suc-input-label'}>{label}</label>}
      <div className={'Suc-right-section'}>
        {optional && <span className={'Suc-optional'}>Optional</span>}
        {info && <TooltipInfo {...infoProps}>{info}</TooltipInfo>}
      </div>

    </div>
    <input className={`Suc-input-field ${error ? 'Suc-error' : ''}`} disabled={disabled} type={type} {...rest} />

    <FieldExtra error={error} warning={warning}/>
  </div>
}

TextInput.propTypes = {
  /** disabled state */
  disabled: PropTypes.bool,
  /** custom classname */
  className: PropTypes.string,
  /** valid html input type */
  type: PropTypes.string,
  /** input label */
  label: PropTypes.string,
  /** input placeholder */
  placeholder: PropTypes.string,
  /** input value */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  /** callback called on change */
  onchange: PropTypes.string,
  /** error text */
  error: PropTypes.string,
  /** warning text */
  warning: PropTypes.string,
  /** remove margin-bottom (to allow inline alignment) */
  removeBottomMargin: PropTypes.bool,
  /** Is the field optional */
  optional: PropTypes.bool,
  /** info tooltip */
  info: PropTypes.node,
  /** InfoTooltip props */
  infoProps: PropTypes.object
}

TextInput.defaultProps = {
  className: '',
  type: 'text',
  error: '',
  warning: '',
  optional: false,
  removeBottomMargin: false,
  infoProps: {}
}

export default TextInput
