import React from 'react'

import WizardContextProvider from "./WizardContext";
import WizardStepTransitionRenderer from "./WizardStepTransitionRenderer";
import WizardFooter from "./WizardFooter";
import WizardHeader from "./WizardHeader";
import Button from "../Button";
import DefaultStepLayout from "./DefaultStepLayout";
import WizardContent from "./WizardContent";
import useWizard from "./useWizard";


export default {
  title: 'Design System/Wizard',

}

const Step1 = {
  Content: () => {
    return <div>I'm step 1</div>
  },
}
const Step2 = {
  Content: () => {
    return <div>I'm step 2</div>
  },
}
const stepsMap = {
  'step-1': Step1,
  'step-2': Step2
}
const stepPaths = {
  regular: [
    {label: 'Step 1', key: 'step-1'},
    {label: 'Step 2', key: 'step-2'},
  ]
}

const WizardWithContext = (args) => <WizardContextProvider {...args}><Template/></WizardContextProvider>;

const Template = () => {
  const { gotoPreviousStep, goToNextStep} = useWizard();
  return <div style={{height: '500px', overflow: 'hidden', border: '1px solid black'}}>
    <DefaultStepLayout>
      <WizardHeader title={'Wizard Name'} logo={<div style={{
        border: '1px solid #006dc9',
        borderRadius: '50%',
        height: '30px',
        width: '30px'
      }}/>} onExit={()=>{}}/>
      <WizardContent>
        <WizardStepTransitionRenderer>
          {({Content: StepContent}) => <StepContent/>}
        </WizardStepTransitionRenderer>
      </WizardContent>
      <WizardFooter>
        <Button thin={true} onClick={gotoPreviousStep} variant={'secondary'}>Previous</Button>
        <Button thin={true} onClick={goToNextStep}>Go</Button>
      </WizardFooter>
    </DefaultStepLayout>
  </div>
}

export const regular = WizardWithContext.bind({})
regular.args = {
  initialStep: 'step-1',
  initialPath: 'regular',
  initialState: {},
  stepsMap,
  stepPaths
}
