const AWS = require('aws-sdk');
const argv = require('yargs').argv;
const {promises: {readdir, readFile}} = require('fs')
const {lstat} = require('fs-extra')

function getS3(accessKeyId, secretAccessKey) {
  return new AWS.S3({accessKeyId, secretAccessKey});
}

async function uploadFile(s3, bucket, key, body) {
  const params = {
    Bucket: bucket,
    Key: key.replace('storybook-static/', ''),
    Body: body,
    ContentType: 'text/html'
  };
  return s3.putObject(params).promise()
}

async function stat(path) {
  const stats = await lstat(path);
  return getType(stats);
}

function getType(stats) {
  let type = 'TYPE_OTHER';
  if (stats.isFile()) {
    type = 'TYPE_FILE';
  } else if (stats.isDirectory()) {
    type = 'TYPE_DIRECTORY';
  } else if (stats.isSymbolicLink()) {
    type = 'TYPE_SYMBOLIC';
  }
  return type;
}

async function uploadDirectory(s3, bucket, dir) {
  const files = await readdir(dir);
  const callbacks = files.map(async file => {
    const fileType = await stat(`${dir}/${file}`)
    if (fileType === 'TYPE_DIRECTORY') {
      return uploadDirectory(s3, bucket, `${dir}/${file}`)
    } else {
      const body = await readFile(`${dir}/${file}`);
      return uploadFile(s3, bucket, `${dir}/${file}`, body)
    }
  });
  return Promise.all(callbacks);
}

async function main(bucket, accessKey, secretKey) {
  console.time('start');
  try {
    const s3 = getS3(accessKey, secretKey)
    await uploadDirectory(s3, bucket, 'storybook-static')
  } catch (e) {
    console.log(e)
  }
  console.timeEnd('start')
}


main('netapp-shared-ui', argv.accessKey, argv.secretKey)

//node cloudOptimizer.js  --accessKey= --secretKey=
